"use strict";

import * as GeneralController from "../../Global/GeneralController.js";
import * as StateGameOver     from "./StateGameOver.js";
import * as StateRunning      from "./StateRunning.js";
import * as StatePaused       from "./StatePaused.js";
import * as UndoManager       from "../../Util/UndoManager.js";
import * as GlobalData        from "../../Global/GlobalData.js";

import { class_RepetitionChecker } from "../../Util/Class_RepetitionChecker.js";

let gameState;
const enumGameState = Object.freeze({
	RUNNING   : 10,
	PAUSED    : 11,
	GAME_OVER : 12
});

const repetitionChecker = new class_RepetitionChecker();
let isPaused;

export function init()
{
	gameState = enumGameState.RUNNING;
	StateRunning.init();
	isPaused = false;
}

export function handleGameTick()
{
	handleInput();
	distributeGameTick();
}

function handleInput()
{
	if (!repetitionChecker.isRepeating(GeneralController.userInput))
	{
		switch (GeneralController.userInput)
		{
			case GlobalData.enumUserInput.ESCAPE : togglePause(); break;
			case GlobalData.enumUserInput.PAUSE  : togglePause(); break;
			case GlobalData.enumUserInput.UNDO   : UndoManager.applyUndo(); break;
			// case GlobalData.enumUserInput.MOVE_UP : switchToGameOver(); break;
		}
	}
}

function togglePause()
{
	isPaused = !isPaused;

	if (isPaused)
	{
		gameState = enumGameState.PAUSED;
	}
	else
	{
		GeneralController.resetMouseClick(); // Negeer mouse-click die tijdens [paused] gedaan is.
		gameState = enumGameState.RUNNING;
	}

	// console.log(`isPaused : '${isPaused}' `);
}

function distributeGameTick()
{
	switch (gameState)
	{
		case enumGameState.RUNNING   : StateRunning.handleGameTick()  ; break;
		case enumGameState.PAUSED    : StatePaused.handleGameTick()   ; break;
		case enumGameState.GAME_OVER : StateGameOver.handleGameTick() ; break;
	}
}

export function switchToGameOver()
{
	gameState = enumGameState.GAME_OVER;
	StateGameOver.init();
}
