"use strict";

import * as GeneralController from "../../Global/GeneralController.js";
import * as coordsContainer   from "./CoordinatesContainer.js";
import * as GlobalData        from "../../Global/GlobalData.js";
import * as Tools             from "../../Util/Tools.js";
import * as View              from "../../Util/View.js";

import { class_TextRow } from "./Class_TextRow.js";
import { class_Point   } from "../../Util/Class_Point.js";
import { class_Delay   } from "../../Util/Class_Delay.js";

const delayTransition  = new class_Delay(75);

export const STAGE_INDEX_NONE = -1;
export let selectedStageIndex = 0;
export const textRowArray = [];

let screenState;
const enumScreenState = Object.freeze({
	NORMAL     : 10,
	TRANSITION : 11
});

let transitionStep;
const TRANSITION_STEP_MIN = 0;
const TRANSITION_STEP_MAX = 10;

export function init()
{
	screenState = enumScreenState.NORMAL;
	transitionStep  = TRANSITION_STEP_MIN;

	coordsContainer.initTextRowCoords();

	for (let i = 0 ; i < GlobalData.STAGE_COUNT ; i++)
	{
		textRowArray[i] = new class_TextRow(i);
	}
}

export function handleGameTick()
{
	if (screenState === enumScreenState.NORMAL)
	{
		handleMouseClick();
		drawContent();
	}
	else if (screenState === enumScreenState.TRANSITION)
	{
		triggerTransition();
	}
}

function handleMouseClick()
{
	// Check of er een muis-click geweest is :
	const X = GeneralController.getClickedLocation()[0];
	const Y = GeneralController.getClickedLocation()[1];
	GeneralController.resetMouseClick();

	if (X > GeneralController.NO_SELECTION && Y > GeneralController.NO_SELECTION)
	{
		const point = new class_Point(X,Y);
		const index  = getSelectedTextRowIndex(point);

		// console.log(`Clicked index  : '${ index }' `);
		// console.log(`Button clicked : '${ coordsContainer.isButtonClicked(point) }' `);
		// console.log(`Clicked point  : '${ point.X},${point.Y }' `);

		if (index > STAGE_INDEX_NONE)
		{
			selectedStageIndex = index;
		}

		if (selectedStageIndex > STAGE_INDEX_NONE && coordsContainer.isButtonClicked(point))
		{
			screenState = enumScreenState.TRANSITION;
		}
	}
}

function getSelectedTextRowIndex(point)
{
	let index = STAGE_INDEX_NONE;

	for (let i = 0 ; i < GlobalData.STAGE_COUNT ; i++)
	{
		const pointStart = textRowArray[i].boundingBoxStartPoint;
		const pointEnd   = textRowArray[i].boundingBoxEndPoint;

		const isWithinBounds = Tools.isLocationWithinBounds(point, pointStart, pointEnd);
		if (isWithinBounds)
		{
			index = i;
			break;
		}
	}
	return index;
}

function drawContent()
{
	const gradient_01 = View.context.createLinearGradient(0,0, 0,GlobalData.CANVAS_HEIGHT);
	gradient_01.addColorStop(0, "black");
	gradient_01.addColorStop(0.25, "red");
	gradient_01.addColorStop(0.75, "red");
	gradient_01.addColorStop(1, "black");
	View.context.fillStyle = gradient_01;
	View.context.fillRect(0,0, GlobalData.CANVAS_WIDTH, GlobalData.CANVAS_HEIGHT);

	//---

	let X;
	let Y = 130;

	let text = "Cluster Tiles";
	View.context.font = "bold 75px Verdana";
	X = Tools.calculateTextXcoordinate(text);
	View.context.fillStyle = "white";
	View.context.fillText(text, X, Y);
	View.context.strokeStyle = "black";
	View.context.strokeText(text, X, Y);

	View.context.shadowColor = "black";
	View.context.shadowOffsetX = 2;
	View.context.shadowOffsetY = 2;
	View.context.shadowBlur = 3;

	Y = 210;
	text = "select the stage you want to play :";
	View.context.font = "24px Verdana";
	X = Tools.calculateTextXcoordinate(text);
	View.context.fillStyle = "yellow";
	View.context.fillText(text, X, Y);

	//---

	Y += 65;
	X = 550;
	View.context.fillText("score :", X, Y);

	X += 150;
	View.context.fillText("hi-score :", X, Y);

	X += 160;
	View.context.fillText("rest :", X, Y);

	//---

	for (let i = 0 ; i < GlobalData.STAGE_COUNT ; i++)
	{
		textRowArray[i].draw();
	}

	X = 550;
	Y = 785;
	const pointButtonStart = new class_Point(X, Y);
	const pointButtonEnd   = new class_Point(X + 120,Y + 45);

	createButton(pointButtonStart, pointButtonEnd);
	coordsContainer.initButtonCoords(pointButtonStart, pointButtonEnd);
	
	X= 40;
	Y = 850;	
	text = "press 'F2' for info";
	View.context.font = "20px Verdana";
	View.context.fillStyle = "gray";
	View.context.fillText(text, X, Y);
	
	View.context.shadowColor = "rgba(0,0,0,0)"; // Restore default-value / turn-off shadowing.
}

function createButton(pointStart, pointEnd)
{
	View.context.lineWidth = 2.0;
	View.context.strokeStyle = "orange";

	View.context.beginPath();
	View.context.moveTo(pointStart.X, pointStart.Y);
	View.context.lineTo(pointEnd.X,   pointStart.Y);
	View.context.lineTo(pointEnd.X,   pointEnd.Y);
	View.context.lineTo(pointStart.X, pointEnd.Y);
	View.context.closePath();
	View.context.stroke();

	View.context.font = "bold 20px Verdana";
	View.context.fillStyle = "orange";
	View.context.fillText("play", pointStart.X + 38, pointStart.Y + 28);
}

//---

function triggerTransition()
{
	if (transitionStep <= TRANSITION_STEP_MAX)
	{
		const HEIGHT = transitionStep * 5;

		drawContent();
		drawBalkje(HEIGHT);

		if (delayTransition.hasExpired())
		{
			transitionStep++;
		}
	}
	else
	{
		screenState = enumScreenState.NORMAL;
		transitionStep = TRANSITION_STEP_MIN;

		GeneralController.switchToPlayScreen();
	}
}

function drawBalkje(height)
{
	const X = Tools.getTileX(0);
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		const Y = Tools.getTileY(row);

		View.context.fillStyle = "orange";
		View.context.fillRect(X, Y,GlobalData.CANVAS_WIDTH, height);
	}
}
