"use strict";

import * as TitleScreen    from "../GeneralStates/TitleScreen/TitleScreen_01.js";
import * as StageContainer from "../Stages/StageContainer.js";
import * as GlobalData     from "./GlobalData.js";
import * as Tools          from "../Util/Tools.js";
import * as View           from "../Util/View.js";
import {ROW_MAX}           from "./GlobalData.js";

export const data = new Array(GlobalData.ROW_COUNT);
export const dataPrevious = new Array(GlobalData.ROW_COUNT);

const explosionLocations = new Map();

const tileMapArray = [];

export function init()
{
	addColumnsToGameField();
}

export function setTile(row, col, tile)
{
	data[row][col] = tile;
}

function addColumnsToGameField()
{
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		data[row] = new Array(GlobalData.COL_COUNT);
		data[row].fill(GlobalData.enumTileNumber.NO_TILE);

		dataPrevious[row] = new Array(GlobalData.COL_COUNT);
		dataPrevious[row].fill(GlobalData.enumTileNumber.NO_TILE);
	}
}

export function render()
{
	drawTiles();
}

function drawTiles()
{
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			drawTile(row, col, data[row][col]);
		}
	}
}

function drawTile(row, col, tileType)
{
	View.context.fillStyle = Tools.getColor(tileType);
	View.context.fillRect(Tools.getTileX(col), Tools.getTileY(row), GlobalData.TILE_SIZE, GlobalData.TILE_SIZE);
}

export function getExplosionLocationsMap()
{
	explosionLocations.clear();

	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			const tileNumber = data[row][col];
			if (Tools.isExplosion(tileNumber))
			{
				const tileLocation = Tools.createTileLocation(row, col);
				explosionLocations.set(tileNumber, tileLocation);
			}
		}
	}
	return explosionLocations;
}

export function addTilesToGameField()
{
	// addRandomTilesToGameField();
	// addTilesToGameField_layers_horizontal();
	// addTilesToGameField_thick_layers_horizontal();
	// addTilesToGameField_bug_01();
	// addTilesToGameField_06();

	const stage = StageContainer.stageMap.get(TitleScreen.selectedStageIndex);

	let i = -1;
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			const tileColor = stage.tileArray[++i];
			data[row][col] = tileColor;
			dataPrevious[row][col] = tileColor;
		}
	}

	updatePreviousData();
}

function addRandomTilesToGameField() // Gebruik dit om nieuwe maps te maken.
{
	// addRandomTilesToGameField_01();
	addRandomTilesToGameField_02();
}

function addRandomTilesToGameField_01()
{
	let stage = "";
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			const randomTileType = Tools.getRandomInteger(11,14);
			data[row][col] = randomTileType;
			stage = stage + `${randomTileType},`;
		}
	}
	console.log(stage);
}

function addRandomTilesToGameField_02()
{
	let stage = "";
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		const tileArray = getRandomTileRow();

		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			const tileType = tileArray.shift()
			data[row][col] = tileType;
			stage = stage + `${tileType},`;
		}
	}
	console.log(stage);
}

function getRandomTileRow()
{
	const tileArray = [];
	while (tileArray.length < GlobalData.COL_COUNT)
	{
		const randomTileType = Tools.getRandomInteger(11,14);
		const length = Tools.getRandomInteger(1,2);

		for (let i = 0 ; i < length ; i++)
		{
			tileArray.push(randomTileType);
		}
	}
	return tileArray;
}

function addTilesToGameField_05() // Scenario 05.
{
	let row = 9;

	data[row][0] = GlobalData.enumTileNumber.RED;
	data[row][1] = GlobalData.enumTileNumber.RED;

	data[row][2] = GlobalData.enumTileNumber.RED;
	data[row][3] = GlobalData.enumTileNumber.RED;

	data[row][4] = GlobalData.enumTileNumber.RED;
	data[row][5] = GlobalData.enumTileNumber.RED;

	data[row][6] = GlobalData.enumTileNumber.GREEN;
	data[row][7] = GlobalData.enumTileNumber.GREEN;

	row--;

	data[row][6] = GlobalData.enumTileNumber.BLUE;
	data[row][7] = GlobalData.enumTileNumber.YELLOW;

	row--;

	data[row][6] = GlobalData.enumTileNumber.BLUE;
	//data[row][7] = GlobalData.enumTileNumber.YELLOW;
}

function addTilesToGameField_06() // Scenario 06.
{
	let row = 9;

	data[row][0] = GlobalData.enumTileNumber.RED;
	data[row][1] = GlobalData.enumTileNumber.RED;

	data[row][2] = GlobalData.enumTileNumber.RED;
	data[row][3] = GlobalData.enumTileNumber.RED;

	data[row][4] = GlobalData.enumTileNumber.RED;
	data[row][5] = GlobalData.enumTileNumber.RED;

	data[row][6] = GlobalData.enumTileNumber.RED;
	data[row][7] = GlobalData.enumTileNumber.RED;

	row--;

	data[row][0] = GlobalData.enumTileNumber.RED;
	data[row][1] = GlobalData.enumTileNumber.BLUE;
	data[row][2] = GlobalData.enumTileNumber.RED;

	data[row][3] = GlobalData.enumTileNumber.YELLOW;

	data[row][4] = GlobalData.enumTileNumber.BLUE;
	data[row][5] = GlobalData.enumTileNumber.BLUE;

	data[row][6] = GlobalData.enumTileNumber.BLUE;
	data[row][7] = GlobalData.enumTileNumber.YELLOW;

	row--;
	data[row][6] = GlobalData.enumTileNumber.BLUE;
	data[row][7] = GlobalData.enumTileNumber.YELLOW;

	row--;
	data[row][7] = GlobalData.enumTileNumber.RED;
	row--;
	data[row][7] = GlobalData.enumTileNumber.RED;
}

function addTilesToGameField_bug_01() 
{
	let row = GlobalData.ROW_MIN;
	let col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.GREEN;

	for (let i = 0 ; i < GlobalData.ROW_MAX ; i++)
	{
		data[++row][col] = GlobalData.enumTileNumber.GREEN;
	}

	row = GlobalData.ROW_MAX;

	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[--row][col] = GlobalData.enumTileNumber.RED;

	row = GlobalData.ROW_MAX;
	col = 2;
	
	for (let i = 0 ; i < 18 ; i++)
	{
		data[row][col] = GlobalData.enumTileNumber.YELLOW;

		row--;
	}	
}

function addTilesToGameField_layers_horizontal() // Tiles in horizontale lagen.
{
	let row = GlobalData.ROW_MAX;
	let col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	
	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;	
	
	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;

	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	//	
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	// data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	// data[row][++col] = GlobalData.enumTileNumber.RED;
	//
	// row--;
	// col = GlobalData.COL_MIN;
	//
	// data[row][col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
	// data[row][++col] = GlobalData.enumTileNumber.BLUE;
}

function addTilesToGameField_thick_layers_horizontal() // Tiles in dikke, horizontale lagen.
{
	let row = GlobalData.ROW_MAX;
	let col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;
	data[row][++col] = GlobalData.enumTileNumber.GREEN;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;
	data[row][++col] = GlobalData.enumTileNumber.YELLOW;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;
	data[row][++col] = GlobalData.enumTileNumber.RED;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;

	row--;
	col = GlobalData.COL_MIN;

	data[row][col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
	data[row][++col] = GlobalData.enumTileNumber.BLUE;
}

// function addTilesToGameField_SAME() // Allemaal dezelfde tiles.
// {
// 	let row = GlobalData.ROW_MAX;
// 	let col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
//
// 	row--;
// 	col = GlobalData.COL_MIN;
//
// 	data[row][col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// 	data[row][++col] = GlobalData.enumTileNumber.GREEN;
// }

export function getUndoData()
{
	const undoDataArray = [];

	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			const tileCurrent  = data[row][col];
			const tilePrevious = dataPrevious[row][col];

			if (!Tools.isExplosion(tileCurrent))
			{
				if (tileCurrent !== tilePrevious)
				{
					const tileDataArray = [];
					tileDataArray.push(row);
					tileDataArray.push(col);
					tileDataArray.push(tilePrevious);

					undoDataArray.push(tileDataArray);
				}
			}
		}
	}

	return undoDataArray;
}

export function updatePreviousData()
{
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			dataPrevious[row][col] = data[row][col];
		}
	}
}
