"use strict";

// Deze module start de game-loop en handelt de key-events af.

import * as GeneralController from "./Global/GeneralController.js";
import * as ImageManager      from "./Util/ImageManager.js";
import * as SoundManager      from "./Util/SoundManager.js";
import * as GlobalData        from "./Global/GlobalData.js";
import * as GameField         from "./Global/GameField.js";
import * as GameLoop          from "./Util/GameLoop.js";
import * as Tools             from "./Util/Tools.js";
import * as View              from "./Util/View.js";

window.addEventListener('keydown', onKeyDown, false);
window.addEventListener('keyup',   onKeyUp,   false);

View.canvas.addEventListener('click', onCanvasMouseClick, false);

function onCanvasMouseClick(event)
{
	const rect = View.canvas.getBoundingClientRect(); // Compenseer page-scrolling.
	const X = Math.trunc(event.clientX - rect.left);
	const Y = Math.trunc(event.clientY - rect.top);

	if (Tools.isMouseClickWithinGameField(X,Y))
	{
		GeneralController.setClickedLocation(X, Y);
	}
}

function onKeyDown(event)
{
	// console.log(`KeyDown : '${event.code}' `);

	switch (event.code)
	{
		case "ArrowUp"    : GeneralController.setUserInput(GlobalData.enumUserInput.MOVE_UP)      ; event.preventDefault(); break;
		case "ArrowDown"  : GeneralController.setUserInput(GlobalData.enumUserInput.MOVE_DOWN)    ; event.preventDefault(); break;
		case "ArrowLeft"  : GeneralController.setUserInput(GlobalData.enumUserInput.MOVE_LEFT)    ; event.preventDefault(); break;
		case "ArrowRight" : GeneralController.setUserInput(GlobalData.enumUserInput.MOVE_RIGHT)   ; event.preventDefault(); break;

		case "F1"         : GeneralController.setUserInput(GlobalData.enumUserInput.TITLE_SCREEN) ; event.preventDefault(); break;
		case "F2"         : GeneralController.setUserInput(GlobalData.enumUserInput.HELP_SCREEN)  ; event.preventDefault(); break;
		case "F3"         : GeneralController.setUserInput(GlobalData.enumUserInput.PLAY_SCREEN)  ; event.preventDefault(); break;

		case "Escape"     : GeneralController.setUserInput(GlobalData.enumUserInput.ESCAPE)       ; event.preventDefault(); break;
		case "KeyP"       : GeneralController.setUserInput(GlobalData.enumUserInput.PAUSE)        ; event.preventDefault(); break;
		case "KeyU"       : GeneralController.setUserInput(GlobalData.enumUserInput.UNDO)         ; event.preventDefault(); break;
	}
}

function onKeyUp()
{
	GeneralController.setUserInput(GlobalData.enumUserInput.NONE);
}

export function initGame()
{
	setCanvasSize();
	loadImages();
}

function setCanvasSize()
{
	View.canvas.width  = GlobalData.CANVAS_WIDTH;
	View.canvas.height = GlobalData.CANVAS_HEIGHT;
}

function loadImages()
{
	ImageManager.loadImages(0, loadSounds);
}

function loadSounds()
{
	SoundManager.loadSounds(startGame);
}

export function startGame()
{
	GameField.init();

	GeneralController.switchToTitleScreen();
	// GeneralController.switchToPlayScreen();

	GameLoop.startGameLoop();
}
