"use strict";

import * as ExplosionManager from "./ExplosionManager.js";
import * as ImageManager     from "./../ImageManager.js";
import * as GameField        from "../../Global/GameField.js";
import * as Tools            from "./../Tools.js";
import * as View             from "../../Util/View.js";

import { class_Delay } from "../Class_Delay.js";

export class class_Explosion
{
	#delayUpdate = new class_Delay(75); // 75

	#isAnimationFinished = false;
	#number;

	#STEP_MAX = 7;
	#step = 0;

	#row; #col;
	#X; #Y;

	constructor(rowAndColArray, explosionNumber)
	{
		this.#number = explosionNumber;

		this.setRow(rowAndColArray[0]);
		this.setCol(rowAndColArray[1]);
	}

	setRow(newRow)
	{
		this.#row = newRow;
		this.#Y = Tools.getTileX(this.#row) - (ExplosionManager.sizeExplosion / 4);
	}

	setCol(newCol)
	{
		this.#col = newCol;
		this.#X = Tools.getTileX(this.#col) - (ExplosionManager.sizeExplosion / 4);
	}

	getRow()
	{
		return this.#row;
	}

	getCol()
	{
		return this.#col;
	}

	updateState()
	{
		if (this.#delayUpdate.hasExpired())
		{
			this.#step++;

			if (this.#step === 1)
			{
				// Zorg dat de tile-kleur 'zwart' wordt nadat de explosie begonnen is.
				GameField.setTile(this.#row, this.#col, this.#number);
			}

			if (this.#step >= this.#STEP_MAX)
			{
				this.isAnimationFinished = true;
			}
		}
	}

	render()
	{
		if (!this.#isAnimationFinished)
		{
			View.context.drawImage(
				ImageManager.images[ImageManager.IMAGE_EXPLOSIONS],    // image
				ExplosionManager.explosionCoordinates[this.#step][0],  // sx
				ExplosionManager.explosionCoordinates[this.#step][1],  // sy
				ExplosionManager.sizeExplosion,                        // sw
				ExplosionManager.sizeExplosion,                        // sh
				this.#X,                                               // dx
				this.#Y,                                               // dy
				ExplosionManager.sizeExplosion,                        // dw
				ExplosionManager.sizeExplosion);                       // dh
		}
	}

}
