"use strict";

export const sizeExplosion = 100;

export const explosionCoordinates = []; // Coordinaten van de verschillende images op de explosie-image-strip.

explosionCoordinates[0]  = [0,                 0];
explosionCoordinates[1]  = [sizeExplosion,     0];
explosionCoordinates[2]  = [sizeExplosion * 2, 0];
explosionCoordinates[3]  = [sizeExplosion * 3, 0];

explosionCoordinates[4]  = [0,                 sizeExplosion];
explosionCoordinates[5]  = [sizeExplosion,     sizeExplosion];
explosionCoordinates[6]  = [sizeExplosion * 2, sizeExplosion];
explosionCoordinates[7]  = [sizeExplosion * 3, sizeExplosion];

const explosionClusterMap = new Map();
let explosionClusterKey = 0;

export function addExplosionCluster(explosionCluster)
{
	explosionClusterMap.set(++explosionClusterKey, explosionCluster);
	if (explosionClusterKey >= 999)
	{
		explosionClusterKey = 0;
	}
}

export function hasExplosions()
{
	return (explosionClusterMap.size > 0);
}

export function updateExplosionWithNewLocations(newExplosionLocationsMap)
{
	for (const key of explosionClusterMap.keys())
	{
		const explosionCluster = explosionClusterMap.get(key);
		explosionCluster.updateExplosionWithNewLocations(newExplosionLocationsMap);
	}
}

export function updateState()
{
	const explosionClustersToDelete = [];
	let isClusterFinished = false;

	for (const key of explosionClusterMap.keys())
	{
		const explosionCluster = explosionClusterMap.get(key);
		if (!explosionCluster.isClusterFinished())
		{
			explosionCluster.updateState();
		}
		else
		{
			explosionClustersToDelete.push(key);
		}
	}

	for (let i = 0 ; i < explosionClustersToDelete.length ; i++)
	{
		const key = explosionClustersToDelete[i];
		explosionClusterMap.delete(key);
		isClusterFinished = true;
	}

	return isClusterFinished;
}

export function render()
{
	for (const key of explosionClusterMap.keys())
	{
		const explosionCluster = explosionClusterMap.get(key);
		explosionCluster.render();
	}
}
