"use strict";

const checkboxSound = document.getElementById("checkboxSound");

let audioContext;
let soundBufferLoader;
let gainNode;

export function loadSounds(myCallback)
{
	audioContext = new AudioContext();
	gainNode = audioContext.createGain();

	soundBufferLoader = new SoundBufferLoader(
		audioContext,
		[
			'../../resources/sounds/sfx_coin_cluster1.wav',
			'../../resources/sounds/sfx_coin_double1.wav',
			'../../resources/sounds/sfx_exp_long1.wav',
			'../../resources/sounds/sfx_exp_medium1.wav',
			'../../resources/sounds/sfx_lowhealth_alarmloop1.wav',
			'../../resources/sounds/sfx_sounds_button1.wav',
			'../../resources/sounds/sfx_sounds_fanfare1.wav',
			'../../resources/sounds/sfx_sounds_fanfare2.wav',
			'../../resources/sounds/sfx_sounds_fanfare3.wav',
			'../../resources/sounds/sfx_exp_short_hard1.wav'
		],
		myCallback
	);

	soundBufferLoader.loadSounds();
}

export function playSoundByIndex(index)
{
	if (!checkboxSound.checked)
	{
		return;
	}
	
	let volume = 0.1;
	switch (index)
	{
		// Stel hier de volumes in van iedere sound
		// zodat alle sounds even luid zijn.

		case 0 : volume = 0.5 ; break;
		case 1 : volume = 0.5 ; break;
		case 2 : volume = 0.5 ; break;
		case 3 : volume = 0.5 ; break;
		case 4 : volume = 0.5 ; break;
		case 5 : volume = 0.5 ; break;
		case 6 : volume = 0.5 ; break;
		case 7 : volume = 0.5 ; break;
		case 8 : volume = 0.5 ; break;
		case 9 : volume = 0.5 ; break;
	}

	playSound(soundBufferLoader.getSoundBuffer(index), volume);
}

function playSound(buffer, volume)
{
	const source = audioContext.createBufferSource(); // Creates a sound source.
	source.buffer = buffer;                           // Tell the source which sound to play.

	source.connect(gainNode);

	gainNode.connect(audioContext.destination); // Connect the source to the context's destination, (the speakers).
	gainNode.gain.value =  volume;

	source.start(0); // Play the source now.
}

//---

export class SoundBufferLoader
{
	#context;
	#urlList;
	#onload;
	#bufferList;
	#loadCount;

	constructor(context, urlList, callback)
	{
		this.#context    = context;
		this.#urlList    = urlList;
		this.#onload     = callback;
		this.#bufferList = [];
		this.#loadCount  = 0;
	}

	loadSounds()
	{
		for (let i = 0 ; i < this.#urlList.length ; ++i)
		{
			this.#loadBuffer(this.#urlList[i], i);
		}
	}

	getSoundBuffer(index)
	{
		return this.#bufferList[index];
	}

	#loadBuffer(url, index)
	{
		// Load buffer asynchronously.
		const request = new XMLHttpRequest();
		request.open("GET", url, true);
		request.responseType = "arraybuffer";

		const loader = this;

		request.onload = function()
		{
			// Asynchronously decode the audio file data in request.response
			loader.#context.decodeAudioData(
				request.response,
				function(buffer)
				{
					if (!buffer)
					{
						alert(`error decoding file data: ${url}`);
						return;
					}

					loader.#bufferList [index] = buffer;
					if (++loader.#loadCount === loader.#urlList.length)
					{
						loader.#onload(loader.#bufferList);
					}
				},
				function(error)
				{
					console.error('decodeAudioData error', error);
				}
			);
		}

		request.onerror = function()
		{
			alert('BufferLoader: XHR error');
		}

		request.send();
	}
}
