"use strict";

import * as GlobalData from "../Global/GlobalData.js";
import * as GameField  from "../Global/GameField.js";
import * as Tools      from "../Util/Tools.js";
import * as View       from "../Util/View.js";

export function render()
{
	drawTileBorders();
}

function drawTileBorders()
{
	for (let row = 0 ; row < GlobalData.ROW_COUNT ; row++)
	{
		for (let col = 0 ; col < GlobalData.COL_COUNT ; col++)
		{
			//--- Top-side :

			const isTouchingGamefieldBorderAbove = isTileTopTouchingGamefieldBorder(row, col);
			const hasDummyTileAbove              = isTileTopTouchingDummyTile(row, col);
			const tileAboveHasDifferentColor     = hasTileAboveDifferentColor(row, col);

			if (isTouchingGamefieldBorderAbove || hasDummyTileAbove || tileAboveHasDifferentColor)
			{
				drawBorderAbove(row, col);
			}

			//--- Left-side :

			const isTouchingGamefieldBorderLeft = isTileLeftTouchingGamefieldBorder(row, col);
			const hasDummyTileLeft              = isTileLeftTouchingDummyTile(row, col);
			const tileLeftHasDifferentColor     = hasTileLeftDifferentColor(row, col);

			if (isTouchingGamefieldBorderLeft || hasDummyTileLeft || tileLeftHasDifferentColor)
			{
				drawBorderLeft(row, col);
			}

			//--- Right-side :

			const isTouchingGamefieldBorderRight = isTileRightTouchingGamefieldBorder(row, col);
			const hasDummyTileRight              = isTileRightTouchingDummyTile(row, col);
			const tileRightHasDifferentColor     = hasTileRightDifferentColor(row, col);

			if (isTouchingGamefieldBorderRight || hasDummyTileRight || tileRightHasDifferentColor)
			{
				drawBorderRight(row, col);
			}

			//--- Bottom-side :

			const isTouchingGamefieldBorderBelow = isTileBottomTouchingGamefieldBorder(row, col);
			const hasDummyTileBelow              = isTileBottomTouchingDummyTile(row, col);
			const tileBelowHasDifferentColor     = hasTileBelowDifferentColor(row, col);

			if (isTouchingGamefieldBorderBelow || hasDummyTileBelow || tileBelowHasDifferentColor)
			{
				drawBorderBelow(row, col);
			}
		}
	}
}

//--- Top-side :

function isTileTopTouchingGamefieldBorder(row, col) // Raakt de [bovenkant] van deze tile de rand ?
{
	const tileType = GameField.data[row][col];
	if (tileType === GlobalData.enumTileNumber.NO_TILE)
	{
		return false;
	}
	else
	{
		return (row === GlobalData.ROW_MIN);
	}
}

function isTileTopTouchingDummyTile(row, col) // Raakt de [bovenkant] van deze tile een lege plek ?
{
	if (row === GlobalData.ROW_MIN)
	{
		return false;
	}
	else
	{
		const tileTypeAbove = GameField.data[row - 1][col];
		return (tileTypeAbove === GlobalData.enumTileNumber.NO_TILE);
	}
}

function hasTileAboveDifferentColor(row, col) // Heeft de tile aan de [bovenkant] een andere kleur dan deze tile ?
{
	if (row === GlobalData.ROW_MIN)
	{
		return false;
	}
	else
	{
		const tileTypeAbove = GameField.data[row - 1][col];
		return (GameField.data[row][col] !== tileTypeAbove);
	}
}

function drawBorderAbove(row, col)
{
	const xTile = Tools.getTileX(col);
	const yTile = Tools.getTileY(row);
	View.context.fillStyle = GlobalData.enumColor.BLACK;
	View.context.fillRect(xTile, yTile, GlobalData.TILE_SIZE, GlobalData.TILE_BORDER_WIDTH);
}

//--- Left-side :

function isTileLeftTouchingGamefieldBorder(row, col) // Raakt de [linkerkant] van deze tile de rand ?
{
	const tileType = GameField.data[row][col];
	if (tileType === GlobalData.enumTileNumber.NO_TILE)
	{
		return false;
	}
	else
	{
		return (col === GlobalData.COL_MIN);
	}
}

function isTileLeftTouchingDummyTile(row, col) // Raakt de [linkerkant] van deze tile een lege plek ?
{
	if (col === GlobalData.COL_MIN)
	{
		return false;
	}
	else
	{
		const tileTypeLeft = GameField.data[row][col - 1];
		return (tileTypeLeft === GlobalData.enumTileNumber.NO_TILE);
	}
}

function hasTileLeftDifferentColor(row, col) // Heeft de tile aan de [linkerkant] een andere kleur dan deze tile ?
{
	if (col === GlobalData.COL_MIN)
	{
		return false;
	}
	else
	{
		const tileTypeLeft = GameField.data[row][col - 1];
		return (GameField.data[row][col] !== tileTypeLeft);
	}
}

function drawBorderLeft(row, col)
{
	const xTile = Tools.getTileX(col);
	const yTile = Tools.getTileY(row);
	View.context.fillStyle = GlobalData.enumColor.BLACK;
	View.context.fillRect(xTile, yTile, GlobalData.TILE_BORDER_WIDTH, GlobalData.TILE_SIZE);
}

//--- Right-side :

function isTileRightTouchingGamefieldBorder(row, col) // Raakt de [rechterkant] van deze tile de rand ?
{
	const tileType = GameField.data[row][col];
	if (tileType === GlobalData.enumTileNumber.NO_TILE)
	{
		return false;
	}
	else
	{
		return (col === GlobalData.COL_MAX);
	}
}

function isTileRightTouchingDummyTile(row, col) // Raakt de [rechterkant] van deze tile een lege plek ?
{
	if (col === GlobalData.COL_MAX)
	{
		return false;
	}
	else
	{
		const tileTypeRight = GameField.data[row][col + 1];
		return (tileTypeRight === GlobalData.enumTileNumber.NO_TILE);
	}
}

function hasTileRightDifferentColor(row, col) // Heeft de tile aan de [rechterkant] een andere kleur dan deze tile ?
{
	if (col === GlobalData.COL_MAX)
	{
		return false;
	}
	else
	{
		const tileTypeRight = GameField.data[row][col + 1];
		return (GameField.data[row][col] !== tileTypeRight);
	}
}

function drawBorderRight(row, col)
{
	const xTile = Tools.getTileX(col) + GlobalData.TILE_SIZE;
	const yTile = Tools.getTileY(row);
	View.context.fillStyle = GlobalData.enumColor.BLACK;
	View.context.fillRect(xTile, yTile, GlobalData.TILE_BORDER_WIDTH, GlobalData.TILE_SIZE);
}

//--- Bottom-side :

function isTileBottomTouchingGamefieldBorder(row, col) // Raakt de [onderkant] van deze tile de rand ?
{
	const tileType = GameField.data[row][col];
	if (tileType === GlobalData.enumTileNumber.NO_TILE)
	{
		return false;
	}
	else
	{
		return (row === GlobalData.ROW_MAX);
	}
}

function isTileBottomTouchingDummyTile(row, col) // Raakt de [onderkant] van deze tile een lege plek ?
{
	if (row === GlobalData.ROW_MAX)
	{
		return false;
	}
	else
	{
		const tileTypeBelow = GameField.data[row + 1][col];
		return (tileTypeBelow === GlobalData.enumTileNumber.NO_TILE);
	}
}

function hasTileBelowDifferentColor(row, col) // Heeft de tile aan de [onderkant] een andere kleur dan deze tile ?
{
	if (row === GlobalData.ROW_MAX)
	{
		return false;
	}
	else
	{
		const tileTypeBelow = GameField.data[row + 1][col];
		return (GameField.data[row][col] !== tileTypeBelow);
	}
}

function drawBorderBelow(row, col)
{
	const xTile = Tools.getTileX(col) + GlobalData.TILE_BORDER_WIDTH;
	const yTile = Tools.getTileY(row) + GlobalData.TILE_SIZE;
	View.context.fillStyle = GlobalData.enumColor.BLACK;
	View.context.fillRect(xTile, yTile, GlobalData.TILE_SIZE, GlobalData.TILE_BORDER_WIDTH);
}
