"use strict";

import * as GlobalData from "../Global/GlobalData.js";
import * as GameField  from "../Global/GameField.js";
import * as Tools      from "../Util/Tools.js";

const tileLocationsFoundArray = [];
const selectedTileLocationsSet = new Set();

export function search(rowClicked, colClicked)
{
	tileLocationsFoundArray.length = 0;
	selectedTileLocationsSet.clear();

	const tileColorTarget = GameField.data[rowClicked][colClicked];

	if (Tools.isValidTile(tileColorTarget))
	{
		storeClickedTile(rowClicked, colClicked);
		selectAdjecentTiles(rowClicked, colClicked, tileColorTarget);
	}

	return selectedTileLocationsSet;
}

function storeClickedTile(row, col)
{
	const tileLocation = Tools.createTileLocation(row,col);
	tileLocationsFoundArray.push(tileLocation);
	selectedTileLocationsSet.add(tileLocation);
}

function selectAdjecentTiles(row, col, tileColorTarget)
{
	while (tileLocationsFoundArray.length > 0)
	{
		const tileLocation = tileLocationsFoundArray.pop();
		const rowAndCol = Tools.getRowAndColArray(tileLocation);
		searchAround(rowAndCol[0], rowAndCol[1], tileColorTarget);
	}
}

function searchAround(row, col, tileColorTarget)
{
	checkAbove(row, col, tileColorTarget);
	checkBelow(row, col, tileColorTarget);
	checkLeft( row, col, tileColorTarget);
	checkRight(row, col, tileColorTarget);
}

function checkAbove(row, col, tileColorTarget)
{
	const rowAbove = row - 1;
	if (rowAbove >= GlobalData.ROW_MIN)
	{
		const tileColor = GameField.data[rowAbove][col];
		if (tileColor === tileColorTarget)
		{
			handlefoundTile(rowAbove, col);
		}
	}
}

function checkBelow(row, col, tileColorTarget)
{
	const rowBelow = row + 1;
	if (rowBelow <= GlobalData.ROW_MAX)
	{
		const tileColor = GameField.data[rowBelow][col];
		if (tileColor === tileColorTarget)
		{
			handlefoundTile(rowBelow, col);
		}
	}
}

function checkLeft(row, col, tileColorTarget)
{
	const colLeft = col - 1;
	if (colLeft >= GlobalData.COL_MIN)
	{
		const tileColor = GameField.data[row][colLeft];
		if (tileColor === tileColorTarget)
		{
			handlefoundTile(row, colLeft);
		}
	}
}

function checkRight(row, col, tileColorTarget)
{
	const colRight = col + 1;
	if (colRight <= GlobalData.COL_MAX)
	{
		const tileColor = GameField.data[row][colRight];
		if (tileColor === tileColorTarget)
		{
			handlefoundTile(row, colRight);
		}
	}
}

function handlefoundTile(row, col)
{
	const tileLocation = Tools.createTileLocation(row,col);
	if (isTileLocationNotYetSelected(tileLocation))
	{
		tileLocationsFoundArray.push(tileLocation);
		selectedTileLocationsSet.add(tileLocation);
	}
}

function isTileLocationNotYetSelected(tileLocation)
{
	return !selectedTileLocationsSet.has(tileLocation);
}
